<?php

/**
 * Freemius functions
 *
 * @package    BoldBlocks
 * @author     Phi Phan <mrphipv@gmail.com>
 * @copyright  Copyright (c) 2022, Phi Phan
 */
namespace BoldBlocks;

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( !function_exists( 'cbb_fs' ) ) {
    // Create a helper function for easy SDK access.
    function cbb_fs()
    {
        global  $cbb_fs ;
        
        if ( !isset( $cbb_fs ) ) {
            // Include Freemius SDK.
            require_once dirname( __FILE__ ) . '/freemius/start.php';
            $cbb_fs = fs_dynamic_init( array(
                'id'             => '11230',
                'slug'           => 'content-blocks-builder',
                'type'           => 'plugin',
                'public_key'     => 'pk_3cf9ea74cc57ecea98583ead30a34',
                'is_premium'     => false,
                'has_addons'     => false,
                'has_paid_plans' => false,
                'menu'           => array(
                'slug'       => 'edit.php?post_type=boldblocks_block',
                'first-path' => 'edit.php?post_type=boldblocks_block&page=cbb-settings',
                'account'    => true,
            ),
                'is_live'        => true,
            ) );
        }
        
        return $cbb_fs;
    }
    
    // Init Freemius.
    cbb_fs();
    // Signal that SDK was initiated.
    do_action( 'cbb_fs_loaded' );
}


if ( !function_exists( 'cbb_fs_custom_connect_message' ) ) {
    /**
     * Customize the opt-in messages
     *
     * @param string $message
     * @param string $user_first_name
     * @param string $plugin_title
     * @param string $user_login
     * @param string $site_link
     * @param string $freemius_link
     * @return string
     */
    function cbb_fs_custom_connect_message(
        $message,
        $user_first_name,
        $plugin_title,
        $user_login,
        $site_link,
        $freemius_link
    )
    {
        return sprintf(
            __( 'Hey %1$s, never miss an important update – opt-in to our security and feature updates notifications, and non-sensitive diagnostic tracking with freemius.com', 'content-blocks-builder' ),
            $user_first_name,
            '<b>' . $plugin_title . '</b>',
            '<b>' . $user_login . '</b>',
            $site_link,
            $freemius_link
        );
    }
    
    cbb_fs()->add_filter(
        'connect_message',
        __NAMESPACE__ . '\\cbb_fs_custom_connect_message',
        10,
        6
    );
}


if ( !function_exists( 'cbb_fs_custom_connect_message_on_update' ) ) {
    /**
     * Customize the opt-in messages
     *
     * @param string $message
     * @param string $user_first_name
     * @param string $plugin_title
     * @param string $user_login
     * @param string $site_link
     * @param string $freemius_link
     * @return string
     */
    function cbb_fs_custom_connect_message_on_update(
        $message,
        $user_first_name,
        $plugin_title,
        $user_login,
        $site_link,
        $freemius_link
    )
    {
        return sprintf(
            __( 'Hey %1$s' ) . ',<br>' . __( 'Please help us improve %2$s! If you opt-in, some data about your usage of %2$s will be sent to %5$s. If you skip this, that\'s okay! %2$s will still work just fine.', 'content-blocks-builder' ),
            $user_first_name,
            '<b>' . $plugin_title . '</b>',
            '<b>' . $user_login . '</b>',
            $site_link,
            $freemius_link
        );
    }
    
    cbb_fs()->add_filter(
        'connect_message_on_update',
        __NAMESPACE__ . '\\cbb_fs_custom_connect_message_on_update',
        10,
        6
    );
}

if ( function_exists( 'fs_override_i18n' ) ) {
    fs_override_i18n( array(
        'opt-in-connect' => __( 'Ok - I am in!', 'content-blocks-builder' ),
        'skip'           => __( 'Maybe later', 'content-blocks-builder' ),
    ), 'content-blocks-builder' );
}